@@ -6,26 +6,37 @@ import json
 import os
 import sys
 # ----- port here. 5000 is flask; is moved to 8000 by gunicorn; to 80 by nginx
-CONFIG={'x':640,
-        'y':480 ,
-        'interpolation':'None',
-        'mintime':0.1,       # normal picture rate
-        'videodev':0,
-        'filename':'~/.config/test/cfg.json',
-        'user':'aaa',
-        'password':'aaa',
-        'port':5000,
-        'change':None,
-        'autoiris':True,
-        'riris':1000,
-        'pantilt':False,
-        'pan':0,
-        'tilt':0,
-        'gamma_adjust':False,
-        'rgain':0,
-        'use_v4l':True,      # zdenek84 had a problem with. I try again
-        'product':"",
-        'quit':False         # this is howto quit
+CONFIG={  'filename':'~/.config/test/cfg.json',
+          'recommended':"",
+          'user':'aaa',
+          'password':'aaa',
+          # ------------------  things for DM ----------
+          'target_frame':'detect',
+          'average':0,
+          'threshold':0,
+          'blur':0,
+          'timelaps':3600,
+          'histogram':False,
+          # ----------------------
+          'resolution':"640x480",
+          #-----------------------
+#          'camera_on':False,   # quewstionable...
+          'x':640,
+          'y':480 ,
+          'interpolation':'None',
+          'mintime':0.1,       # normal picture rate
+          'videodev':0,
+          'port':5000,
+          'change':None,
+          'autoiris':True,
+          'riris':1000,
+          'pantilt':False,
+          'pan':0,
+          'tilt':0,
+          'gamma_adjust':False,
+          'rgain':0,
+          'use_v4l':True,      # zdenek84 had a problem with. I try again
+          'quit':False         # this is howto quit
 
 }
 
@@ -87,7 +98,7 @@ def cfg_to_bak(filenamebk="", filename = ""):
     #print("D... cfg:",cfg)
     #print("D... cfgbak:",cfgbak)
     #if CFG_DEBUG:
-    print("D... creating a backup config:", cfgbak )
+    #print("D... creating a backup config:", cfgbak )
     if not os.path.isfile( os.path.expanduser(cfg)):
         print(f"X... config {cfg} doesnt exist (yet?, OK)")
         return True
@@ -116,10 +127,10 @@ def bak_to_cfg(filenamebk="", filename = ""):
 
     cfgbak = cfg + ".bak"
     #if CFG_DEBUG:
-    print("D... testing if backup config exists:", cfgbak)
+    #print("D... testing if backup config exists:", cfgbak)
     if os.path.isfile( os.path.expanduser(cfgbak)):
         #if CFG_DEBUG:
-        print("D... BACUP config exists:",cfgbak, "... renaming to:", cfg)
+        #print("D... BACUP config exists:",cfgbak, "... renaming to:", cfg)
         os.rename(os.path.expanduser(cfgbak),
                   os.path.expanduser(cfg))
         #if CFG_DEBUG:print("D... config is recovered from:", cfgbak)
@@ -139,7 +150,7 @@ def save_config(filenamesv="", filename = ""): # duplicit... filename overrides
     else:
         cfg = filenamesv
 
-    print("D... calling cfg_to_bak:", cfg)
+    #print("D... calling cfg_to_bak:", cfg)
     if not cfg_to_bak(cfg):
         sys.exit(1)
 
@@ -159,8 +170,11 @@ def save_config(filenamesv="", filename = ""): # duplicit... filename overrides
 
     if verify_config(filename):
         #if CFG_DEBUG:
-        print("D... verified by verify_config ... ok ... ending here")
+        #print("D... verified by verify_config ... ok ... ending here")
         return True
+    else:
+        print("D... verified by verify_config ... NOT ok ... ending here")
+        return False
     #====ELSE RECOVER BAK
     return bak_to_cfg()
 
@@ -174,8 +188,8 @@ def load_config(filename=""):
     cfg = CONFIG['filename']
     cfg = cfg+".from_memory"
     #if CFG_DEBUG:
-    print("D... calling save_config:")
-    save_config( cfg )
+    #print("D... calling save_config to frommemory:")
+    save_config( cfg ) # from_memory file
 
     cfg = CONFIG['filename']
     #if CFG_DEBUG:print("D... loading config from",cfg)
@@ -197,7 +211,8 @@ def load_config(filename=""):
     # rewriting in memory
     if sorted(dicti.keys()) == sorted(CONFIG.keys()):
         #if CFG_DEBUG:
-        print("D... memory and disk identical:")
+        #print("D... memory and disk identical:")
+        pass
     else:
         #if CFG_DEBUG:
         print("X... memory and disk differ:")
@@ -211,10 +226,10 @@ def load_config(filename=""):
 
     CONFIG = dicti
     #if CFG_DEBUG:
-    print("D... final CONFIG:")
+    #print("D... final CONFIG:")
     #show_config(filename)
     #if CFG_DEBUG:
-    print("D... end load")
+    #print("D... end load")
 
 
 def loadsave(filename = ""):
