@@ -66,12 +66,12 @@ def test_config_save():
     print( config.get_config_file() )
     return config.save_config()
 
-def test_config_read():
-    config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
-    config.load_config()
-    config.show_config()
-    print( config.get_config_file() )
-    assert config.save_config() == True
+# def test_config_read():
+#     config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
+#     config.load_config()
+#     config.show_config()
+#     print( config.get_config_file() )
+#     assert config.save_config() == True
 
 def test_func():
     print("i... TESTING function func")
@@ -156,10 +156,10 @@ def show_cam(vidnum, res, recommended=""):
     while True:
 
         timeoutok = False
-        ret = False
+        ret = True
         frame = None
         if (cap is None) or (not cap.isOpened()):
-            print("X... camera None or not Opened)")
+            print("X... camera None or not Opened")
             ret = False
         else:
             try: #----this catches errors of libjpeg with cv2.CAP_V4L2
@@ -180,6 +180,7 @@ def show_cam(vidnum, res, recommended=""):
 
         if not ret:
             time.sleep(0.5)
+            print("D... trying to recommend")
             vids = recommend_video(recommended) # try to re-init the same video
             if len(vids)>0:
                 vidnum = vids[0]
@@ -205,6 +206,7 @@ def show_cam(vidnum, res, recommended=""):
                 cv2.imshow( wname , frame );
                 k = cv2.waitKey(1)
                 if k == ord("q"):
+                    #camera.kill = True
                     break
 
 
@@ -269,6 +271,7 @@ def recommend_video( prefname="" ):
         print(i)
     #print("D... this was serial devices")
 
+    recommvid=[]
     vids=glob.glob("/dev/video*")
     print("____________________video   devices _______"+"_"*37)
     print(f"video bus dev UsbTyp vendor:model   product            IDpath            capabi")
@@ -296,11 +299,13 @@ def recommend_video( prefname="" ):
                 id_path = [x for x in res.split() if x.find("ID_PATH=")>=0][0]
                 id_path = id_path.split("=")[1]
                 id_path = ":".join( id_path.split(":")[2:] )
+                ok = True
             except  Exception as ex:
                 print("X... udevadm error...", ex, vid)
                 ok = False
 
             if ok:
+                print(f"D...  getting capabilities", )
                 cc = V4L2_CTL( vid )
                 capa = cc.get_capbilities()
                 GE = ""
@@ -324,15 +329,27 @@ def recommend_video( prefname="" ):
                         #if self.verbose:print("     ",vendor, model, vname)
                     print(f"{vidid:2d}   {bus:4s} {dev:4s} {usb_hubs[bus]:6s} {vendor:4s}:{model:4s}  {name:20s}  {id_path:16s}  {len(capa)}{GE}   {pref}" )
                     # verify_resolutions( vidid, resolutions )
-
-    print("_"*80)
-    print(recomvid)
+            # print(prefname, recomvid)
+    print("|"*80)
+    if str(prefname)!="":
+        if len(recomvid)==0:
+            print("X... config WANTS the camera",prefname)
+            print("X... NOT FOUND")
+    print("D... recommending:",recomvid)
+    print("i... recommending:",recomvid)
+    print("i... recommending:",recomvid)
+    print("i... recommending:",recomvid)
+    print("i... recommending:",recomvid)
 
     #resolutions = get_resolutions( recomvid[0] )
     # show_cam( recomvid[0], resolutions[-1] )
 
     return recomvid
 
+
+
+
+
 if __name__ == "__main__":
     print("i... in the __main__ of unitname of flashcam")
     Fire(recommend_video)
