@@ -59,6 +59,10 @@ class V4L2_Control:
     def setdef_value(self):
         return self.change_value(self.default)
 
+    # uuuuuiiiiiiiiii ---works
+    def getdef_value(self):
+        return self.default
+
     def change_value(self, value):
         try:
             value = int(value)
@@ -145,6 +149,7 @@ class V4L2_CTL():
             setattr(self, "getmax_" + control.name, control.getmax_value)
             setattr(self, "setdef_" + control.name, control.setdef_value)
             setattr(self, "get_" + control.name, control.get_value)
+            setattr(self, "getdef_" + control.name, control.getdef_value)
 
     def get_capbilities_as_json(self):
         return json.dumps([x.asdict() for x in self.controls])
@@ -157,6 +162,21 @@ class V4L2_CTL():
         return ca
 
 
+    # def refresh(self):
+    #     super(V4L2_CTL, self).__init__()
+    #     self.controls = self._list_controls()
+    #     self.capabilities = []
+    #     self.update_capabilities()
+    #     for control in self.controls:
+    #         #print(control.name)
+    #         setattr(self, "set_" + control.name, control.change_value)
+    #         setattr(self, "getmin_" + control.name, control.getmin_value)
+    #         setattr(self, "getmax_" + control.name, control.getmax_value)
+    #         setattr(self, "setdef_" + control.name, control.setdef_value)
+    #         setattr(self, "get_" + control.name, control.get_value)
+    #         setattr(self, "getdef_" + control.name, control.getdef_value)
+
+
     def update_capabilities(self):
         self.capabilities = [x.name for x in self.controls]
 
@@ -235,18 +255,18 @@ def func(debug = False):
     print("X... in unit unitname function func - ALERT")
     return True
 
-def test_config_save():
-    config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
-    config.show_config()
-    print( config.get_config_file() )
-    return config.save_config()
+# def test_config_save():
+#     config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
+#     config.show_config()
+#     print( config.get_config_file() )
+#     return config.save_config()
 
-def test_config_read():
-    config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
-    config.load_config()
-    config.show_config()
-    print( config.get_config_file() )
-    assert config.save_config() == True
+# def test_config_read():
+#     config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
+#     config.load_config()
+#     config.show_config()
+#     print( config.get_config_file() )
+#     assert config.save_config() == True
 
 def test_func():
     print("i... TESTING function func")
@@ -337,6 +357,9 @@ def tune_histo(cc, h_avg):
 
 
 def main( devid ):
+    """
+    Here it is a test to set exposure and gain by histogram
+    """
     #cam = Device.from_id(0)
     #print( cam.info)
     #print()
@@ -369,63 +392,89 @@ def main( devid ):
         cc.setdef_exposure_absolute()
 
     gain= 0
+
+    #create two subplots
+    ax1 = plt.subplot(1,2,1)
+    ax2 = plt.subplot(1,2,2)
+    lineGray, = ax2.plot(np.arange(bins), np.zeros((bins,1)), c='r', lw=lw)
+    ax2.set_xlim(-10, bins + 10)
+
     while(True):# https://github.com/nrsyed/computer-vision/blob/master/real_time_histogram/real_time_histogram.py
         #print(" ... gain,  exposure   ",cc.get_gain(), cc.get_exposure_absolute() )
 
         ret, frame = vid.read()
-        if initme:
-            #create two subplots
-            ax1 = plt.subplot(1,2,1)
-            ax2 = plt.subplot(1,2,2)
+        # if initme:
 
-            lineGray, = ax2.plot(np.arange(bins), np.zeros((bins,1)), c='r', lw=lw)
-            ax2.set_xlim(-10, bins + 10)
-            #ax2.set_ylim(0, 1)
-            ax1.set_axis_off()
-            ax2.spines['right'].set_visible(False)
-            #ax.spines['bottom'].set_visible(False)
-            ax2.spines['left'].set_visible(False)
-            #ax2.set_axis_off()
-            #create two image plots
-            im1 = ax1.imshow(frame)
-            #im2 = ax2.imshow(frame)
-            #plt.autoscale(enable=True, axis='x', tight=True)
-            #ax1 = plt.gca()  # only to illustrate what `ax` is
-            #ax1.autoscale(enable=True, axis='both', tight=True)
-            #ax2.autoscale(enable=True, axis='both', tight=True)
-            plt.rcParams['axes.xmargin'] = 0
-            plt.rcParams['axes.ymargin'] = 0
-            plt.ion()
-            plt.show()
-            initme = False
+        #     #ax2.set_ylim(0, 1)
+        #     ax1.set_axis_off()
+        #     ax2.spines['right'].set_visible(False)
+        #     #ax.spines['bottom'].set_visible(False)
+        #     ax2.spines['left'].set_visible(False)
+        #     #ax2.set_axis_off()
+
+        #     #create two image plots
+        #     im1 = ax1.imshow(frame)
+
+        #     #im2 = ax2.imshow(frame)
+        #     #plt.autoscale(enable=True, axis='x', tight=True)
+        #     #ax1 = plt.gca()  # only to illustrate what `ax` is
+        #     #ax1.autoscale(enable=True, axis='both', tight=True)
+        #     #ax2.autoscale(enable=True, axis='both', tight=True)
+        #     plt.rcParams['axes.xmargin'] = 0
+        #     plt.rcParams['axes.ymargin'] = 0
+        #     plt.ion()
+        #     ####print("i... plt show")
+        #     #plt.show()
+        #     #plt.pause(0.01)
+        #     initme = False
 
         framegray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
         hist = cv2.calcHist([framegray], [0], None, [256], [0, 256])
         hist = cv2.normalize(hist, hist).flatten()
         hist /= hist.sum()
 
-        h_avg = (hist*np.arange(bins)).sum()
-        h_std = ((hist*np.arange(bins)*np.arange(bins)).sum())**0.5
-        #gg = cc.get_gain()
-        #gex = cc.get_exposure_absolute()
-        #print(np.arange(bins))
-        #print("===================")
-        #print(hist.sum(), "SUM",hist )
-        #print("===================")
-        #print(hist*np.arange(bins))
+        #h_avg = (hist*np.arange(bins)).sum()
+        #h_std = ((hist*np.arange(bins)*np.arange(bins)).sum())**0.5
 
 
+        #------------------ https://stackoverflow.com/questions/9390592/drawing-histogram-in-opencv-python
+        #h = np.zeros((300,256,3))
+        h = np.zeros((480,640,3))
+        h = frame.copy()
+        #h = np.flipud(h)
 
-        gg,ex = tune_histo(cc, h_avg)
-        print(f" g={gg} e={ex}   {h_avg:.1f} ({h_std:.1f}) ", end = "\r" )
+        BINS = 64
+        bins = np.arange(BINS).reshape(BINS,1)
+        color = [ (255,0,0),(0,255,0),(0,0,255) ]
+
+        for ch, col in enumerate(color):
+            hist_item = cv2.calcHist([frame],[ch],None,[BINS],[0,255])
+            cv2.normalize(hist_item,hist_item, 0, 255, cv2.NORM_MINMAX)
+            hist=np.int32(np.around(hist_item))
+            pts = np.column_stack((bins*int(640/BINS),480-(hist*480/255).astype(int)))
+            cv2.polylines(h,[pts],False,col)
+
+        framegray = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
+        hist_gray = cv2.calcHist([framegray], [0], None, [BINS], [0, 255])
+        cv2.normalize(hist_gray,hist_gray,0,255,cv2.NORM_MINMAX)
+        hist=np.int32(np.around(hist_gray))
+        pts = np.column_stack((bins*int(640/BINS),480-(hist*480/255).astype(int)))
+        cv2.polylines(h,[pts], False,  [255,255,255], thickness= 2 )
 
 
-        im1.set_data(frame)
-        #plt.imshow(frame)
-        lineGray.set_ydata(hist)
-        #print(hist.mean(), hist.min(), hist.max(), hist.std() )
-        #plt.show()#fig.canvas.draw()
-        #cv2.imshow("f1",frame)
+        #h=np.flipud(h)
+
+        cv2.imshow('colorhist',h)
+        #cv2.waitKey(1)
+
+
+        #gg,ex = tune_histo(cc, h_avg)
+        #print(f" g={gg} e={ex}   {h_avg:.1f} ({h_std:.1f}) ", end = "\r" )
+
+
+        #im1.set_data(frame)
+        #lineGray.set_ydata(hist)
+
         if cv2.waitKey(1) & 0xFF == ord('q'):
             break
 
