@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # to override print <= can be a big problem with exceptions
-from __future__ import print_function # must be 1st
-import builtins
+#from __future__ import print_function # must be 1st
+#import builtins
 '''
 This is flask interface
 '''
@@ -44,17 +44,29 @@ app = Flask(__name__)
 
 
 #==================== ALL config changes must be here ============
-config.load_config()
+#  1st 'filename'   2nd load !!!!!!!!!!!!!!!!!
+print( "i... USER  web:", config.CONFIG['user'] )
 config.CONFIG['filename'] = "~/.config/flashcam/cfg.json"
-config.CONFIG['camera_on'] = False
-config.show_config()
+config.load_config()
+print( "i... USER  web:", config.CONFIG['user'] )
+
+config.CONFIG['camera_on'] = False # for everyone - nobodyhas the camera at this point
+if  not("debug" in config.CONFIG):
+    config.CONFIG['debug'] = True
 
 
-Camera = Camera # creating the OBJECT
+#config.show_config()
+
+# CONFIG WILL BE SAVED WHEN RUN FROM MAIN
 
 
+# Camera = Camera #  This was a lucky error.... CLass from Class
+# it appears - flask works when I run directly the class .....
 
 
+cross_dx, cross_dy = 0,0
+cross_on = False
+
 
 
 
@@ -72,42 +84,6 @@ remote_ip=""
 auth = HTTPBasicAuth()
 
 #---not fstring- {} would colide
-index_page_refresh30 = """
- <meta http-equiv="refresh" content="30";>
-
-<html>
-<script>
-function doDate()
-{
-    var str = "";
-
-    var days = new Array("Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday");
-    var months = new Array("January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December");
-
-    var now = new Date();
-
-    str +=  now.getHours() +":" + now.getMinutes() + ":" + now.getSeconds();
-    document.getElementById("todaysDate").innerHTML = str;
-}
-
-setInterval(doDate, 200);
-</script>
-  <head>
-    <title>Video Streaming</title>
-  </head>
-  <body>
-
-<p>
-<div id="todaysDate"></div>
-</p>
-    <!--h1>Video Streaming Demonstration</h1-->
-    <img src="{{url}}">
-<br>
-
-  </body>
-</html>
-
-"""
 
 
 index_page = """
@@ -124,7 +100,7 @@ function doDate()
 
     var now = new Date();
 
-    str +=  now.getHours() +":" + now.getMinutes() + ":" + now.getSeconds();
+    str += " &nbsp; &nbsp;&nbsp;&nbsp;" +  now.getHours() +":" + (now.getMinutes() < 10 ? '0' : '') + now.getMinutes() + ":" + (now.getSeconds() < 10 ? '0' : '') + now.getSeconds() ;
     document.getElementById("todaysDate").innerHTML = str;
 }
 
@@ -135,12 +111,34 @@ setInterval(doDate, 200);
   </head>
   <body>
 
-<p>
+
 <div id="todaysDate"></div>
-</p>
-    <!--h1>Video Streaming Demonstration</h1-->
+
     <img src="{{url}}">
 <br>
+<form method="post" action="/cross">
+  <div class="btn-group" style="width:100%">
+      <button style="width:20%" name="up2" value="UP2">up2</button>
+  </div>
+  <div class="btn-group" style="width:100%">
+      <button style="width:20%" name="up" value="UP">up</button>
+      <button style="width:10%" name="crosson" value="CROSSON">CROSSON</button>
+  </div>
+  <div class="btn-group" style="width:100%">
+      <button style="width:3%" name="left2" value="LEFT2"> << </button>
+      <button style="width:3%" name="left" value="LEFT"> < </button>
+      <button style="width:3%" name="center" value="CENTER"> o </button>
+      <button style="width:3%" name="right" value="RIGHT"> > </button>
+      <button style="width:3%" name="right2" value="RIGHT2"> >> </button>
+  </div>
+  <div class="btn-group" style="width:100%">
+      <button style="width:20%" name="down" value="DOWN">down</button>
+      <button style="width:10%" name="crossoff" value="CROSSOFF">CROSSOFF</button>
+  </div>
+  <div class="btn-group" style="width:100%">
+      <button style="width:20%" name="down2" value="DOWN2">down2</button>
+  </div>
+</form>
 
   </body>
 </html>
@@ -148,6 +146,85 @@ setInterval(doDate, 200);
 """
 #    <img src="{{ url_for('video') }}">
 
+def crossonw( img,  dix, diy):
+    RADIUS=63
+    y = int(img.shape[0]/2)
+    x = int(img.shape[1]/2)
+
+    ix = x+dix
+    iy = y+diy
+
+    i2=cv2.circle( img, (ix,iy), RADIUS, (0,255,55), 1)
+    i2=cv2.line(i2, (ix-RADIUS+5,iy), (ix-5,iy), (0, 255, 55), thickness=1, lineType=8)
+    i2=cv2.line(i2, (ix+RADIUS-5,iy), (ix+5,iy), (0, 255, 55), thickness=1, lineType=8)
+
+    i2=cv2.line(i2, (ix,iy-RADIUS+5), (ix,iy-5), (0, 255, 55), thickness=1, lineType=8)
+    i2=cv2.line(i2, (ix,iy+RADIUS-5), (ix,iy+5), (0, 255, 55), thickness=1, lineType=8)
+
+    i2=cv2.line(i2, (ix,iy), (ix,iy), (0, 255, 55), thickness=1, lineType=8)
+    return img
+
+
+@auth.verify_password
+@app.route("/cross", methods=['GET', 'POST'])
+def cross():
+    global cross_dx, cross_dy, cross_on
+
+    # i will read it from file
+    crocfg = os.path.expanduser("~/.config/flashcam/cross.txt")
+    if os.path.exists(crocfg):
+        with open(crocfg) as f:
+           cross_dx, cross_dy  = [int(x) for x in next(f).split()]
+
+    print(request.method)
+    if request.method == 'POST':
+        if cross_on:
+            if request.form.get('left2') == 'LEFT2':
+                print("left2")
+                cross_dx-= 50
+            if request.form.get('left') == 'LEFT':
+                print("left")
+                cross_dx-= 5
+            if request.form.get('center') == 'CENTER':
+                print("center")
+                cross_dx= 0
+                cross_dy= 0
+            elif  request.form.get('right') == 'RIGHT':
+                print("right")
+                cross_dx+= 5
+            elif  request.form.get('right2') == 'RIGHT2':
+                print("right2")
+                cross_dx+= 50
+            elif  request.form.get('up') == 'UP':
+                print("up")
+                cross_dy-= 5
+            elif  request.form.get('up2') == 'UP2':
+                print("up2")
+                cross_dy-= 50
+            elif  request.form.get('down') == 'DOWN':
+                print("down")
+                cross_dy+= 5
+            elif  request.form.get('down2') == 'DOWN2':
+                print("down2")
+                cross_dy+= 50
+
+        if  request.form.get('crosson') == 'CROSSON':
+            print("ON")
+            cross_on = True
+        elif  request.form.get('crossoff') == 'CROSSOFF':
+            print("OFF")
+            cross_on = False
+
+        with open(crocfg,"w") as f:
+            f.write(f"{cross_dx} {cross_dy}")
+
+    remote_ip=request.environ.get('HTTP_X_REAL_IP', request.remote_addr)
+    logthis( " / remote      = "+request.remote_addr )
+    logthis( " / remote xreal= "+remote_ip )
+    url = url_for('video')
+    return render_template_string(index_page, url=url)
+
+
 
 
 @auth.verify_password
@@ -186,7 +263,6 @@ def verify_password(username, password):
 def index():
     global remote_ip
     """Video streaming home page."""
-    print("W... asking INDEX.HTML")
     remote_ip=request.environ.get('HTTP_X_REAL_IP', request.remote_addr)
     logthis( " / remote      = "+request.remote_addr )
     logthis( " / remote xreal= "+remote_ip )
@@ -220,6 +296,7 @@ def video():
     #---------------this is MJPEG-------------------------
     #config.CONFIG["product"] = "Webcam C270"
     # return Response(gen(Camera(config.CONFIG["product"], "640x480"),remote_ip),
+    # --- i send here the CLASS ?????
     return Response(gen(Camera(),remote_ip),
                     mimetype='multipart/x-mixed-replace; boundary=frame')
 
@@ -241,34 +318,36 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
     while True:
         time.sleep(0.1)
         framecnt+=1
-        print("D... get_frame (gen)")
+        #print("D... get_frame (gen)")
         frame = camera.get_frame()
-        print("D... got_frame (gen)")
+        #print("D... got_frame (gen)")
         start = dt.datetime.now()
         blackframe = np.zeros((480,640,3), np.uint8)
         #frame = blackframe
         if blend:
             frame = 0.5*frame + 0.5*imgs[ random.randint(0,len(imgs)-1) ]
 
-        if bigtext:
-            frame = cv2.putText(
-                img = frame,
-                text = dt.datetime.now().strftime("%H:%M:%S"),
-                org = (10, 100),
-                fontFace = cv2.FONT_HERSHEY_DUPLEX,
-                fontScale = 2.0,
-                color = (125, 246, 55),
-                thickness = 3
-            )
-            frame = cv2.putText(
-                img = frame,
-                text = f"{framecnt:6d} {ss_time:.3f}",
-                org = (10, 50),
-                fontFace = cv2.FONT_HERSHEY_DUPLEX,
-                fontScale = 1.0,
-                color = (125, 246, 55),
-                thickness = 1
-            )
+        if cross_on:
+            frame = crossonw( frame, cross_dx, cross_dy )
+        # if bigtext:
+        #     frame = cv2.putText(
+        #         img = frame,
+        #         text = dt.datetime.now().strftime("%H:%M:%S"),
+        #         org = (10, 100),
+        #         fontFace = cv2.FONT_HERSHEY_DUPLEX,
+        #         fontScale = 2.0,
+        #         color = (125, 246, 55),
+        #         thickness = 3
+        #     )
+        #     frame = cv2.putText(
+        #         img = frame,
+        #         text = f"{framecnt:6d} {ss_time:.3f}",
+        #         org = (10, 50),
+        #         fontFace = cv2.FONT_HERSHEY_DUPLEX,
+        #         fontScale = 1.0,
+        #         color = (125, 246, 55),
+        #         thickness = 1
+        #     )
         #----- i dont send None now, but this helped to avoid crash
         if not(frame is None):
             frame=cv2.imencode('.jpg', frame)[1].tobytes()
@@ -285,26 +364,28 @@ def gen(camera, remote_ip, blend=False, bigtext=True):
                b'Content-Type: image/jpeg\r\n\r\n' + frame + b'\r\n')
 
 
-@app.before_first_request
-def debug_print():
+# @app.before_first_request
+# def debug_print():
 
-    class Bcolors:
-        HEADER = '[95m'
-        OKBLUE = '[94m'
-        OKGREEN = '[92m'
-        WARNING = '[93m'
-        FAIL = '[91m'
-        ENDC = '[0m'
-        BOLD = '[1m'
-        UNDERLINE = '[4m'
+#     class Bcolors:
+#         HEADER = '[95m'
+#         OKBLUE = '[94m'
+#         OKGREEN = '[92m'
+#         WARNING = '[93m'
+#         FAIL = '[91m'
+#         ENDC = '[0m'
+#         BOLD = '[1m'
+#         UNDERLINE = '[4m'
 
-    if True:
-        _print = print # keep a local copy of the original print
-        builtins.print =lambda *args, **kwargs:  None  if (isinstance(args[0], str)) and (args[0].find("D...")==0) else  _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.ENDC) , *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
-    else:
-        # debug - show all + colors
-        _print = print # keep a local copy of the original print
-        builtins.print =lambda *args, **kwargs:   _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.OKGREEN if  ((isinstance(args[0], str)) and (args[0].find("i...")>=0)) else Bcolors.ENDC  ), *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
+#         #    if not(config.CONFIG["debug"]):
+#         print("X... NO DEBUG colors in main")
+#         _print = print # keep a local copy of the original print
+#         builtins.print =lambda *args, **kwargs:  None  if (isinstance(args[0], str)) and (args[0].find("D...")==0) else  _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.ENDC) , *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
+# #    else:
+# #        print("X... DEBUG COLORS FROM MAIN")
+# #        # debug - show all + colors
+# #        _print = print # keep a local copy of the original print
+# #        builtins.print =lambda *args, **kwargs:   _print( *args, **kwargs) if ('file' in kwargs) else _print( "{}".format(Bcolors.FAIL   if ((isinstance(args[0], str)) and (args[0].find("X...")>=0)) else Bcolors.OKGREEN if  ((isinstance(args[0], str)) and (args[0].find("i...")>=0)) else Bcolors.ENDC  ), *args, Bcolors.ENDC, **kwargs, file=sys.stderr)
 
 
 if __name__ == '__main__':
